package com.jiuqi.util.chinese;

import java.io.Serializable;

class ChineseDigit implements Comparable, Cloneable, Serializable {
   private static final char[] SMALL_DIGITS = new char[]{'○', '一', '二', '三', '四', '五', '六', '七', '八', '九'};
   private static final char[] BIG_DIGITS = new char[]{'零', '壹', '贰', '叁', '肆', '伍', '陆', '柒', '捌', '玖'};
   private static char bufferedChar = 0;
   private static int bufferedValue = -1;
   private int digit;

   public ChineseDigit() {
      this.digit = 0;
   }

   public ChineseDigit(int dig) {
      if (dig >= 0 && dig <= 9) {
         this.digit = dig;
      } else {
         throw new IllegalArgumentException("只能从0-9的阿拉伯数字来建立对象！");
      }
   }

   public ChineseDigit(char digChar) throws NotValidChineseDigitException {
      int value = digChar - 48;
      if (value >= 0 && value <= 9) {
         this.digit = value;
      } else {
         this.digit = valueOf(digChar);
      }

   }

   public int intValue() {
      return this.digit;
   }

   public char chineseValue(boolean useBigChar) {
      return toChineseChar(this.digit, useBigChar);
   }

   public static int valueOf(char chDig) throws NotValidChineseDigitException {
      if (bufferedChar == chDig) {
         return bufferedValue;
      } else {
         int position = -1;

         int i;
         for(i = 0; i < SMALL_DIGITS.length; ++i) {
            if (chDig == SMALL_DIGITS[i]) {
               position = i;
               break;
            }
         }

         if (position != -1) {
            bufferedChar = chDig;
            bufferedValue = position;
            return position;
         } else {
            for(i = 0; i < BIG_DIGITS.length; ++i) {
               if (chDig == BIG_DIGITS[i]) {
                  position = i;
                  break;
               }
            }

            if (position != -1) {
               bufferedChar = chDig;
               bufferedValue = position;
               return position;
            } else {
               throw new NotValidChineseDigitException("字符\"" + chDig + "\"不是一个中文的数字字符！");
            }
         }
      }
   }

   public static char toChineseChar(int value, boolean useBigChar) {
      if (value >= 0 && value <= 9) {
         return !useBigChar ? SMALL_DIGITS[value] : BIG_DIGITS[value];
      } else {
         throw new IllegalArgumentException("整型参数值\"" + value + "\"必须在0-9之间！");
      }
   }

   public static boolean isValidChineseDigit(char value) {
      try {
         valueOf(value);
         return true;
      } catch (NotValidChineseDigitException var1) {
         return false;
      }
   }

   public Object clone() {
      return new ChineseDigit(this.digit);
   }

   public boolean equals(Object o) {
      if (o == this) {
         return true;
      } else if (!(o instanceof ChineseDigit)) {
         return false;
      } else {
         ChineseDigit value = (ChineseDigit)o;
         return this.digit == value.digit;
      }
   }

   public int hashCode() {
      int result = super.hashCode();
      int hc1 = this.digit;
      result = 37 * result + hc1;
      return result;
   }

   public String toString() {
      return String.valueOf(this.chineseValue(false));
   }

   public int compareTo(Object o) {
      ChineseDigit value = (ChineseDigit)o;
      return this.digit - value.digit;
   }
}
